@@ -1,8 +1,6 @@
 package DateTimeX::Format::Excel;
-BEGIN {
-  $DateTimeX::Format::Excel::AUTHORITY = 'cpan:JANDREW';
-}
-use version 0.77; our $VERSION = qv("v0.12.26");
+our $AUTHORITY = 'cpan:JANDREW';
+use version 0.77; our $VERSION = version->declare("v0.12.28");
 use	5.010;
 use	strict;
 use	warnings;
@@ -192,13 +190,29 @@ DateTimeX::Format::Excel - Microsofty conversion of Excel epochs
 
 =begin html
 
-<a href="https://travis-ci.org/jandrew/DateTimeX-Format-Excel"><img alt="Build Status" src="https://travis-ci.org/jandrew/DateTimeX-Format-Excel.png?branch=master" alt='Travis Build'/></a>
+<a href="https://www.perl.org">
+	<img src="https://img.shields.io/badge/perl-5.10+-brightgreen.svg" alt="perl version">
+</a>
 
-<a href="https://img.shields.io/badge"><img src="https://img.shields.io/badge/perl-5.10+-brightgreen.svg" alt="perl version"></a>
+<a href="https://travis-ci.org/jandrew/DateTimeX-Format-Excel">
+	<img alt="Build Status" src="https://travis-ci.org/jandrew/DateTimeX-Format-Excel.png?branch=master" alt='Travis Build'/>
+</a>
 
-<a href='https://coveralls.io/r/jandrew/DateTimeX-Format-Excel?branch=master'><img src='https://coveralls.io/repos/jandrew/DateTimeX-Format-Excel/badge.svg?branch=master' alt='Coverage Status' /></a>
+<a href='https://coveralls.io/r/jandrew/DateTimeX-Format-Excel?branch=master'>
+	<img src='https://coveralls.io/repos/jandrew/DateTimeX-Format-Excel/badge.svg?branch=master' alt='Coverage Status' />
+</a>
 
-<a href='http://cpants.cpanauthors.org/dist/DateTimeX-Format-Excel'><img src='http://cpants.cpanauthors.org/dist/DateTimeX-Format-Excel.png' alt='kwalitee' height="19"/></a>
+<a>
+	<img src="https://img.shields.io/badge/this version-0.12.28-brightgreen.svg" alt="this version">
+</a>
+
+<a href="https://metacpan.org/pod/DateTimeX::Format::Excel">
+	<img src="https://badge.fury.io/pl/DateTimeX-Format-Excel.svg?label=cpan version" alt="CPAN version" height="20">
+</a>
+
+<a href='http://cpants.cpanauthors.org/dist/DateTimeX-Format-Excel'>
+	<img src='http://cpants.cpanauthors.org/dist/DateTimeX-Format-Excel.png' alt='kwalitee' height="20"/>
+</a>
 
 =end html
 
@@ -519,7 +533,7 @@ it and/or modify it under the same terms as Perl itself.
 The full text of the license can be found in the
 LICENSE file included with this module.
 
-This software is copyrighted (c) 2014,2015 by Jed Lund
+This software is copyrighted (c) 2014 - 2015 by Jed Lund
 
 =head1 DEPENDENCIES
 
