@@ -1,8 +1,6 @@
 package DateTimeX::Format::Excel::Types;
-BEGIN {
-  $DateTimeX::Format::Excel::Types::AUTHORITY = 'cpan:JANDREW';
-}
-use version; our $VERSION = version->declare("v0.12.26");
+our $AUTHORITY = 'cpan:JANDREW';
+use version; our $VERSION = version->declare("v0.12.28");
 use	5.010;
 use strict;
 use warnings;
